@@ -19,14 +19,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "kipiexportaction.moc"
+#include "kipiexportaction.h"
 
 // Qt
 #include <QMenu>
 
 // KDE
-#include <KDebug>
-#include <KMenu>
+#include <QMenu>
 #include <KLocale>
 
 // Local
@@ -45,7 +44,7 @@ struct KIPIExportActionPrivate
 
     void updateMenu()
     {
-        KMenu* menu = static_cast<KMenu*>(q->menu());
+        QMenu* menu = static_cast<QMenu*>(q->menu());
         menu->clear();
 
         if (mDefaultAction) {
@@ -69,7 +68,7 @@ struct KIPIExportActionPrivate
 };
 
 KIPIExportAction::KIPIExportAction(QObject* parent)
-: KToolBarPopupAction(KIcon("document-share"), i18nc("@action", "Share"), parent)
+: KToolBarPopupAction(QIcon::fromTheme("document-share"), i18nc("@action", "Share"), parent)
 , d(new KIPIExportActionPrivate)
 {
     d->q = this;
@@ -108,7 +107,7 @@ void KIPIExportAction::init()
         disconnect(menu(), SIGNAL(aboutToShow()), this, SLOT(init()));
     } else {
         // Loading is in progress, come back when it is done
-        connect(d->mKIPIInterface, SIGNAL(loadingFinished()), SLOT(init()));
+        connect(d->mKIPIInterface, &KIPIInterface::loadingFinished, this, &KIPIExportAction::init);
     }
     d->updateMenu();
 }
