@@ -19,26 +19,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "cropwidget.moc"
 
 // Qt
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QPushButton>
-#include <QtCore/qmath.h>
+#include <QtMath>
+#include <QDebug>
+#include <QLineEdit>
 
 // KDE
-#include <KDebug>
 #include <KDialog>
 #include <KGlobalSettings>
-#include <KLineEdit>
-#include <KLocale>
+#include <KLocalizedString>
 
 // Local
 #include <lib/documentview/rasterimageview.h>
 #include "croptool.h"
 #include "signalblocker.h"
 #include "ui_cropwidget.h"
+#include "cropwidget.h"
 
 namespace Gwenview
 {
@@ -155,13 +155,13 @@ struct CropWidgetPrivate : public Ui_CropWidget
         addRatioToComboBox(QSizeF(8.5, 11), i18n("US Letter"));
 
         ratioComboBox->setMaxVisibleItems(ratioComboBox->count());
-        ratioComboBox->setEditText(QString());
+        ratioComboBox->clearEditText();
 
-        KLineEdit* edit = qobject_cast<KLineEdit*>(ratioComboBox->lineEdit());
+        QLineEdit* edit = qobject_cast<QLineEdit*>(ratioComboBox->lineEdit());
         Q_ASSERT(edit);
         // Do not use i18n("%1:%2") because ':' should not be translated, it is
         // used to parse the ratio string.
-        edit->setClickMessage(QString("%1:%2").arg(i18n("Width")).arg(i18n("Height")));
+        edit->setPlaceholderText(QString("%1:%2").arg(i18n("Width")).arg(i18n("Height")));
     }
 
     QRect cropRect() const
@@ -187,13 +187,11 @@ struct CropWidgetPrivate : public Ui_CropWidget
     void initDialogButtonBox()
     {
         QPushButton* cropButton = dialogButtonBox->button(QDialogButtonBox::Ok);
-        cropButton->setIcon(KIcon("transform-crop-and-resize"));
+        cropButton->setIcon(QIcon::fromTheme("transform-crop-and-resize"));
         cropButton->setText(i18n("Crop"));
 
-        QObject::connect(dialogButtonBox, SIGNAL(accepted()),
-                         q, SIGNAL(cropRequested()));
-        QObject::connect(dialogButtonBox, SIGNAL(rejected()),
-                         q, SIGNAL(done()));
+        QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, q, &CropWidget::cropRequested);
+        QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, q, &CropWidget::done);
     }
 };
 
@@ -218,22 +216,16 @@ CropWidget::CropWidget(QWidget* parent, RasterImageView* imageView, CropTool* cr
 
     d->initRatioComboBox();
 
-    connect(d->mCropTool, SIGNAL(rectUpdated(QRect)),
-            SLOT(setCropRect(QRect)));
+    connect(d->mCropTool, &CropTool::rectUpdated, this, &CropWidget::setCropRect);
 
-    connect(d->leftSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotPositionChanged()));
-    connect(d->topSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotPositionChanged()));
-    connect(d->widthSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotWidthChanged()));
-    connect(d->heightSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotHeightChanged()));
+    connect(d->leftSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
+    connect(d->topSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
+    connect(d->widthSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotWidthChanged);
+    connect(d->heightSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotHeightChanged);
 
     d->initDialogButtonBox();
 
-    connect(d->ratioComboBox, SIGNAL(editTextChanged(QString)),
-            SLOT(slotRatioComboBoxEditTextChanged()));
+    connect(d->ratioComboBox, &QComboBox::editTextChanged, this, &CropWidget::slotRatioComboBoxEditTextChanged);
 
     // Don't do this before signals are connected, otherwise the tool won't get
     // initialized
