@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "loadingdocumentimpl.moc"
+#include "loadingdocumentimpl.h"
 
 // STL
 #include <memory>
@@ -33,17 +33,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QImage>
 #include <QImageReader>
 #include <QPointer>
-#include <QtConcurrentRun>
+#include <QtConcurrent>
+#include <QUrl>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
 #include <KIO/Job>
 #include <KIO/JobClasses>
-#include <KLocale>
-#include <KMimeType>
+#include <KLocalizedString>
 #include <KProtocolInfo>
-#include <KUrl>
+
+#ifdef KDCRAW_FOUND
 #include <libkdcraw/kdcraw.h>
+#endif
 
 // Local
 #include "animateddocumentloadedimpl.h"
@@ -69,7 +71,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) //qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -111,11 +113,12 @@ struct LoadingDocumentImplPrivate
     bool determineKind()
     {
         QString mimeType;
-        const KUrl& url = q->document()->url();
-        if (KProtocolInfo::determineMimetypeFromExtension(url.protocol())) {
-            mimeType = KMimeType::findByNameAndContent(url.fileName(), mData)->name();
+        const QUrl &url = q->document()->url();
+        QMimeDatabase db;
+        if (KProtocolInfo::determineMimetypeFromExtension(url.scheme())) {
+            mimeType = db.mimeTypeForFileNameAndData(url.fileName(), mData).name();
         } else {
-            mimeType = KMimeType::findByContent(mData)->name();
+            mimeType = db.mimeTypeForData(mData).name();
         }
         MimeTypeUtils::Kind kind = MimeTypeUtils::mimeTypeKind(mimeType);
         LOG("mimeType:" << mimeType);
@@ -168,7 +171,7 @@ struct LoadingDocumentImplPrivate
             break;
 
         default:
-            kWarning() << "We should not reach this point!";
+            qWarning() << "We should not reach this point!";
             break;
         }
     }
@@ -190,6 +193,7 @@ struct LoadingDocumentImplPrivate
         buffer.setBuffer(&mData);
         buffer.open(QIODevice::ReadOnly);
 
+#ifdef KDCRAW_FOUND
         if (KDcrawIface::KDcraw::rawFilesList().contains(QString(mFormatHint))) {
             QByteArray previewData;
 
@@ -206,7 +210,7 @@ struct LoadingDocumentImplPrivate
                 // half preview instead. That's slower but it works even for images containing
                 // small (160x120px) or none embedded preview.
                 if (!KDcrawIface::KDcraw::loadHalfPreview(previewData, buffer)) {
-                    kWarning() << "unable to get half preview for " << q->document()->url().fileName();
+                    qWarning() << "unable to get half preview for " << q->document()->url().fileName();
                     return false;
                 }
             }
@@ -219,23 +223,26 @@ struct LoadingDocumentImplPrivate
             // need to fill mFormat so gwenview can tell the type when trying to save
             mFormat = mFormatHint;
         } else {
+#else
+{
+#endif
             QImageReader reader(&buffer, mFormatHint);
             mImageSize = reader.size();
 
             if (!reader.canRead()) {
-                kWarning() << "QImageReader::read() using format hint" << mFormatHint << "failed:" << reader.errorString();
+                qWarning() << "QImageReader::read() using format hint" << mFormatHint << "failed:" << reader.errorString();
                 if (buffer.pos() != 0) {
-                    kWarning() << "A bad Qt image decoder moved the buffer to" << buffer.pos() << "in a call to canRead()! Rewinding.";
+                    qWarning() << "A bad Qt image decoder moved the buffer to" << buffer.pos() << "in a call to canRead()! Rewinding.";
                     buffer.seek(0);
                 }
                 reader.setFormat(QByteArray());
                 // Set buffer again, otherwise QImageReader won't restart from scratch
                 reader.setDevice(&buffer);
                 if (!reader.canRead()) {
-                    kWarning() << "QImageReader::read() without format hint failed:" << reader.errorString();
+                    qWarning() << "QImageReader::read() without format hint failed:" << reader.errorString();
                     return false;
                 }
-                kWarning() << "Image format is actually" << reader.format() << "not" << mFormatHint;
+                qWarning() << "Image format is actually" << reader.format() << "not" << mFormatHint;
             }
 
             mFormat = reader.format();
@@ -262,7 +269,7 @@ struct LoadingDocumentImplPrivate
         if (mJpegContent.get()) {
             if (!mJpegContent->loadFromData(mData, mExiv2Image.get()) &&
                 !mJpegContent->loadFromData(mData)) {
-                kWarning() << "Unable to use preview of " << q->document()->url().fileName();
+                qWarning() << "Unable to use preview of " << q->document()->url().fileName();
                 return false;
             }
             // Use the size from JpegContent, as its correctly transposed if the
@@ -337,7 +344,7 @@ struct LoadingDocumentImplPrivate
                 LOG("Really an animated image (more than one frame)");
                 mAnimated = true;
             } else {
-                kWarning() << q->document()->url() << "is not really an animated image (only one frame)";
+                qWarning() << q->document()->url() << "is not really an animated image (only one frame)";
             }
         }
     }
@@ -378,7 +385,7 @@ LoadingDocumentImpl::~LoadingDocumentImpl()
 
 void LoadingDocumentImpl::init()
 {
-    KUrl url = document()->url();
+    QUrl url = document()->url();
 
     if (UrlUtils::urlIsFastLocalFile(url)) {
         // Load file content directly
@@ -397,7 +404,7 @@ void LoadingDocumentImpl::init()
         d->startLoading();
     } else {
         // Transfer file via KIO
-        d->mTransferJob = KIO::get(document()->url());
+        d->mTransferJob = KIO::get(document()->url(), KIO::NoReload, KIO::HideProgressInfo);
         connect(d->mTransferJob, SIGNAL(data(KIO::Job*,QByteArray)),
                 SLOT(slotDataReceived(KIO::Job*,QByteArray)));
         connect(d->mTransferJob, SIGNAL(result(KJob*)),
