@@ -17,16 +17,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "placetreemodeltest.moc"
+#include "placetreemodeltest.h"
 
 // Qt
 #include <QDir>
 #include <QFile>
 
 // KDE
-#include <KDebug>
+#include <QDebug>
 #include <KStandardDirs>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 // Local
 #include "../lib/placetreemodel.h"
@@ -34,7 +34,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 //#define KEEP_TEMP_DIR
 
-QTEST_KDEMAIN(PlaceTreeModelTest, GUI)
+QTEST_MAIN(PlaceTreeModelTest)
 
 using namespace Gwenview;
 
@@ -76,12 +76,12 @@ void PlaceTreeModelTest::initTestCase()
     const bool dir1created = dir.mkdir("url1");
     Q_ASSERT(dir1created);
     Q_UNUSED(dir1created);
-    mUrl1 = KUrl::fromPath(dir.filePath("url1"));
+    mUrl1 = QUrl::fromLocalFile(dir.filePath("url1"));
 
     const bool dir2created = dir.mkdir("url2");
     Q_ASSERT(dir2created);
     Q_UNUSED(dir2created);
-    mUrl2 = KUrl::fromPath(dir.filePath("url2"));
+    mUrl2 = QUrl::fromLocalFile(dir.filePath("url2"));
 
     mUrl1Dirs << "aaa" << "zzz" << "bbb";
     Q_FOREACH(const QString & dirName, mUrl1Dirs) {
@@ -90,7 +90,7 @@ void PlaceTreeModelTest::initTestCase()
 
 #ifdef KEEP_TEMP_DIR
     mTempDir.setAutoRemove(false);
-    kDebug() << "mTempDir:" << mTempDir.name();
+    //qDebug() << "mTempDir:" << mTempDir.name();
 #endif
 }
 
@@ -111,7 +111,7 @@ void PlaceTreeModelTest::init()
 
 #ifdef KEEP_TEMP_DIR
     mTempDir.setAutoRemove(false);
-    kDebug() << "mTempDir:" << mTempDir.name();
+    //qDebug() << "mTempDir:" << mTempDir.name();
 #endif
 }
 
