@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
-#include "timeutilstest.moc"
+#include "timeutilstest.h"
 
 // libc
 #include <utime.h>
@@ -26,14 +26,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // KDE
 #include <KFileItem>
 #include <KTemporaryFile>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 // Local
 #include "../lib/timeutils.h"
 
 #include "testutils.h"
 
-QTEST_KDEMAIN(TimeUtilsTest, GUI)
+QTEST_MAIN(TimeUtilsTest)
 
 using namespace Gwenview;
 
@@ -46,12 +46,12 @@ static void touchFile(const QString& path)
 void TimeUtilsTest::testBasic_data()
 {
     QTest::addColumn<QString>("fileName");
-    QTest::addColumn<KDateTime>("expectedDateTime");
+    QTest::addColumn<QDateTime>("expectedDateTime");
 
-    NEW_ROW("date/exif-datetimeoriginal.jpg", KDateTime::fromString("2003-03-10T17:45:21"));
-    NEW_ROW("date/exif-datetime-only.jpg", KDateTime::fromString("2003-03-25T02:02:21"));
+    NEW_ROW("date/exif-datetimeoriginal.jpg", QDateTime::fromString("2003-03-10T17:45:21"));
+    NEW_ROW("date/exif-datetime-only.jpg", QDateTime::fromString("2003-03-25T02:02:21"));
 
-    KUrl url = urlForTestFile("test.png");
+    QUrl url = urlForTestFile("test.png");
     KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url);
     NEW_ROW("test.png", item.time(KFileItem::ModificationTime));
 }
@@ -59,9 +59,9 @@ void TimeUtilsTest::testBasic_data()
 void TimeUtilsTest::testBasic()
 {
     QFETCH(QString, fileName);
-    QFETCH(KDateTime, expectedDateTime);
-    KDateTime dateTime;
-    KUrl url = urlForTestFile(fileName);
+    QFETCH(QDateTime, expectedDateTime);
+    QDateTime dateTime;
+    QUrl url = urlForTestFile(fileName);
     KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url);
 
     dateTime = TimeUtils::dateTimeForFileItem(item);
@@ -75,16 +75,16 @@ void TimeUtilsTest::testCache()
 {
     KTemporaryFile tempFile;
     QVERIFY(tempFile.open());
-    KUrl url = KUrl::fromLocalFile(tempFile.fileName());
+    QUrl url = QUrl::fromLocalFile(tempFile.fileName());
     KFileItem item1(KFileItem::Unknown, KFileItem::Unknown, url);
-    KDateTime dateTime1 = TimeUtils::dateTimeForFileItem(item1);
+    QDateTime dateTime1 = TimeUtils::dateTimeForFileItem(item1);
     QCOMPARE(dateTime1, item1.time(KFileItem::ModificationTime));
 
     QTest::qWait(1200);
     touchFile(url.toLocalFile());
 
     KFileItem item2(KFileItem::Unknown, KFileItem::Unknown, url);
-    KDateTime dateTime2 = TimeUtils::dateTimeForFileItem(item2);
+    QDateTime dateTime2 = TimeUtils::dateTimeForFileItem(item2);
 
     QVERIFY(dateTime1 != dateTime2);
 
